# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"ImageLabeler": "20_Image_Labeler.ipynb",
         "SingleClassImageLabeler": "20_Image_Labeler.ipynb",
         "MultiClassImageLabeler": "20_Image_Labeler.ipynb"}

modules = ["turk/image.py"]

doc_url = "https://raynardj.github.io/unpackai/"

git_url = "https://github.com/raynardj/unpackai/tree/master/"

def custom_doc_links(name): return None
